"""Sphinx Bootstrap Theme package."""
import os
from setuptools import setup, find_packages

from jupyter_sphinx_theme import __version__

###############################################################################
# Environment and Packages.
###############################################################################
# Don't copy Mac OS X resource forks on tar/gzip.
os.environ['COPYFILE_DISABLE'] = "true"

# Packages.
MOD_NAME = "jupyter_sphinx_theme"
PKGS = [x for x in find_packages() if x.split('.')[0] == MOD_NAME]


###############################################################################
# Helpers.
###############################################################################
def read_file(name):
    """Read file name (without extension) to string."""
    cur_path = os.path.dirname(__file__)
    exts = ('txt', 'rst', 'md')
    for ext in exts:
        path = os.path.join(cur_path, '.'.join((name, ext)))
        if os.path.exists(path):
            with open(path, 'rt') as file_obj:
                return file_obj.read()

    return ''


###############################################################################
# Setup.
###############################################################################
setup(
    name="jupyter-sphinx-theme",
    version=__version__,
    use_2to3=True,
    description="Jupyter Sphinx Theme.",
    long_description=read_file("README"),
    url="http://github.com/jupyter/sphinx-theme",

    author="Ryan Roemer, Project Jupyter, and contributors",
    author_email="jupyter@googlegroups.com",

    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Intended Audience :: System Administrators",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Topic :: Internet",
        "Topic :: Software Development :: Documentation",
    ],

    install_requires=[
        "setuptools",
        "recommonmark==0.4.0",
        "nbsphinx"
    ],

    packages=PKGS,
    include_package_data=True,
)



"""Jupyter sphinx theme."""
import os
import subprocess
import sys

on_rtd = os.environ.get('READTHEDOCS', None) == 'True'

def get_html_theme_path():
    """Return list of HTML theme paths."""
    cur_dir = os.path.abspath(os.path.dirname(__file__))
    return [cur_dir]

def bash(fileName):
    """Runs a bash script in the local directory"""
    sys.stdout.flush()
    subprocess.call("bash {}".format(fileName), shell=True)

VERSION = (0, 0, 6)
__version__ = ".".join(str(v) for v in VERSION)
__version_full__ = __version__
theme_version = __version__

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
source_suffix = ['.rst', '.ipynb']

# Conf.py import settings
source_parsers = {}
def init_theme():
    from recommonmark.parser import CommonMarkParser
    source_parsers['.md'] = CommonMarkParser
    source_suffix.append('.md')

html_theme = 'jupyter'
html_theme_path = get_html_theme_path()

extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.intersphinx',
    'sphinx.ext.mathjax',
    'nbsphinx'
]

html_sidebars = {
    '**': [
        'sidebartoc.html'
    ]
}
